@@ -211,9 +211,12 @@ static PyObject *
 _wrap_vte_terminal_get_audible_bell(PyGObject *self)
 {
     int ret;
+    PyObject *py_ret;
 
     ret = vte_terminal_get_audible_bell(VTE_TERMINAL(self->obj));
-    return PyInt_FromLong(ret);
+    py_ret = ret ? Py_True : Py_False;
+    Py_INCREF(py_ret);
+    return py_ret;
 }
 
 static PyObject *
@@ -233,9 +236,25 @@ static PyObject *
 _wrap_vte_terminal_get_visible_bell(PyGObject *self)
 {
     int ret;
+    PyObject *py_ret;
 
     ret = vte_terminal_get_visible_bell(VTE_TERMINAL(self->obj));
-    return PyInt_FromLong(ret);
+    py_ret = ret ? Py_True : Py_False;
+    Py_INCREF(py_ret);
+    return py_ret;
+}
+
+static PyObject *
+_wrap_vte_terminal_set_scroll_background(PyGObject *self, PyObject *args, PyObject *kwargs)
+{
+    static char *kwlist[] = { "scroll", NULL };
+    int scroll;
+
+    if (!PyArg_ParseTupleAndKeywords(args, kwargs, "i:VteTerminal.set_scroll_background", kwlist, &scroll))
+        return NULL;
+    vte_terminal_set_scroll_background(VTE_TERMINAL(self->obj), scroll);
+    Py_INCREF(Py_None);
+    return Py_None;
 }
 
 static PyObject *
@@ -264,6 +283,26 @@ _wrap_vte_terminal_set_scroll_on_keystroke(PyGObject *self, PyObject *args, PyOb
     return Py_None;
 }
 
+static PyObject *
+_wrap_vte_terminal_set_color_dim(PyGObject *self, PyObject *args, PyObject *kwargs)
+{
+    static char *kwlist[] = { "dim", NULL };
+    PyObject *py_dim;
+    GdkColor *dim = NULL;
+
+    if (!PyArg_ParseTupleAndKeywords(args, kwargs, "O:VteTerminal.set_color_dim", kwlist, &py_dim))
+        return NULL;
+    if (pyg_boxed_check(py_dim, GDK_TYPE_COLOR))
+        dim = pyg_boxed_get(py_dim, GdkColor);
+    else {
+        PyErr_SetString(PyExc_TypeError, "dim should be a GdkColor");
+        return NULL;
+    }
+    vte_terminal_set_color_dim(VTE_TERMINAL(self->obj), dim);
+    Py_INCREF(Py_None);
+    return Py_None;
+}
+
 static PyObject *
 _wrap_vte_terminal_set_color_bold(PyGObject *self, PyObject *args, PyObject *kwargs)
 {
@@ -369,7 +408,7 @@ _wrap_vte_terminal_set_colors(PyGObject *self, PyObject *args, PyObject *kwargs)
     Py_INCREF(Py_None);
     return Py_None;
 }
-#line 373 "vte.c"
+#line 412 "vte.c"
 
 
 static PyObject *
@@ -406,6 +445,26 @@ _wrap_vte_terminal_set_background_image_file(PyGObject *self, PyObject *args, Py
     return Py_None;
 }
 
+static PyObject *
+_wrap_vte_terminal_set_background_tint_color(PyGObject *self, PyObject *args, PyObject *kwargs)
+{
+    static char *kwlist[] = { "color", NULL };
+    PyObject *py_color;
+    GdkColor *color = NULL;
+
+    if (!PyArg_ParseTupleAndKeywords(args, kwargs, "O:VteTerminal.set_background_tint_color", kwlist, &py_color))
+        return NULL;
+    if (pyg_boxed_check(py_color, GDK_TYPE_COLOR))
+        color = pyg_boxed_get(py_color, GdkColor);
+    else {
+        PyErr_SetString(PyExc_TypeError, "color should be a GdkColor");
+        return NULL;
+    }
+    vte_terminal_set_background_tint_color(VTE_TERMINAL(self->obj), color);
+    Py_INCREF(Py_None);
+    return Py_None;
+}
+
 static PyObject *
 _wrap_vte_terminal_set_background_saturation(PyGObject *self, PyObject *args, PyObject *kwargs)
 {
@@ -518,9 +577,12 @@ static PyObject *
 _wrap_vte_terminal_get_using_xft(PyGObject *self)
 {
     int ret;
+    PyObject *py_ret;
 
     ret = vte_terminal_get_using_xft(VTE_TERMINAL(self->obj));
-    return PyInt_FromLong(ret);
+    py_ret = ret ? Py_True : Py_False;
+    Py_INCREF(py_ret);
+    return py_ret;
 }
 
 static PyObject *
@@ -540,18 +602,24 @@ static PyObject *
 _wrap_vte_terminal_get_allow_bold(PyGObject *self)
 {
     int ret;
+    PyObject *py_ret;
 
     ret = vte_terminal_get_allow_bold(VTE_TERMINAL(self->obj));
-    return PyInt_FromLong(ret);
+    py_ret = ret ? Py_True : Py_False;
+    Py_INCREF(py_ret);
+    return py_ret;
 }
 
 static PyObject *
 _wrap_vte_terminal_get_has_selection(PyGObject *self)
 {
     int ret;
+    PyObject *py_ret;
 
     ret = vte_terminal_get_has_selection(VTE_TERMINAL(self->obj));
-    return PyInt_FromLong(ret);
+    py_ret = ret ? Py_True : Py_False;
+    Py_INCREF(py_ret);
+    return py_ret;
 }
 
 static PyObject *
@@ -572,6 +640,7 @@ _wrap_vte_terminal_is_word_char(PyGObject *self, PyObject *args, PyObject *kwarg
 {
     static char *kwlist[] = { "c", NULL };
     int ret;
+    PyObject *py_ret;
     gunichar c;
     Py_UNICODE *py_c = NULL;
 
@@ -583,7 +652,9 @@ _wrap_vte_terminal_is_word_char(PyGObject *self, PyObject *args, PyObject *kwarg
     }
     c = (gunichar)py_c[0];
     ret = vte_terminal_is_word_char(VTE_TERMINAL(self->obj), c);
-    return PyInt_FromLong(ret);
+    py_ret = ret ? Py_True : Py_False;
+    Py_INCREF(py_ret);
+    return py_ret;
 }
 
 static PyObject *
@@ -635,9 +706,12 @@ static PyObject *
 _wrap_vte_terminal_get_mouse_autohide(PyGObject *self)
 {
     int ret;
+    PyObject *py_ret;
 
     ret = vte_terminal_get_mouse_autohide(VTE_TERMINAL(self->obj));
-    return PyInt_FromLong(ret);
+    py_ret = ret ? Py_True : Py_False;
+    Py_INCREF(py_ret);
+    return py_ret;
 }
 
 static PyObject *
@@ -706,7 +780,7 @@ _wrap_vte_terminal_get_text(PyGObject *self, PyObject *args, PyObject *kwargs)
     }
 
     if (do_attr != NULL && do_attr != Py_None) {
-	attrs = g_array_new(FALSE, TRUE, sizeof(struct vte_char_attributes));
+	attrs = g_array_new(FALSE, TRUE, sizeof(VteCharAttributes));
     } else {
     	attrs = NULL;
     }
@@ -749,11 +823,11 @@ _wrap_vte_terminal_get_text(PyGObject *self, PyObject *args, PyObject *kwargs)
     if (attrs) {
 	py_attrs = PyTuple_New(attrs->len);
 	for (count = 0; count < attrs->len; count++) {
-	    struct vte_char_attributes *cht;
+	    VteCharAttributes *cht;
 	    PyObject *py_char_attr;
 	    PyObject *py_gdkcolor;
 
-	    cht = &g_array_index(attrs, struct vte_char_attributes, count);
+	    cht = &g_array_index(attrs, VteCharAttributes, count);
 	    py_char_attr = PyDict_New();
 	    PyDict_SetItemString(py_char_attr, "row", PyInt_FromLong(cht->row));
 	    PyDict_SetItemString(py_char_attr, "column", PyInt_FromLong(cht->column));
@@ -776,7 +850,7 @@ _wrap_vte_terminal_get_text(PyGObject *self, PyObject *args, PyObject *kwargs)
     	return Py_BuildValue("O", text);
     }
 }
-#line 780 "vte.c"
+#line 854 "vte.c"
 
 
 #line 213 "vte.override"
@@ -801,7 +875,7 @@ _wrap_vte_terminal_get_text_range(PyGObject *self, PyObject *args, PyObject *kwa
     }
 
     if (do_attr != NULL && do_attr != Py_None) {
-	attrs = g_array_new(FALSE, TRUE, sizeof(struct vte_char_attributes));
+	attrs = g_array_new(FALSE, TRUE, sizeof(VteCharAttributes));
     } else {
     	attrs = NULL;
     }
@@ -846,11 +920,11 @@ _wrap_vte_terminal_get_text_range(PyGObject *self, PyObject *args, PyObject *kwa
     if (attrs) {
 	py_attrs = PyTuple_New(attrs->len);
 	for (count = 0; count < attrs->len; count++) {
-	    struct vte_char_attributes *cht;
+	    VteCharAttributes *cht;
 	    PyObject *py_char_attr;
 	    PyObject *py_gdkcolor;
 
-	    cht = &g_array_index(attrs, struct vte_char_attributes, count);
+	    cht = &g_array_index(attrs, VteCharAttributes, count);
 	    py_char_attr = PyDict_New();
 	    PyDict_SetItemString(py_char_attr, "row", PyInt_FromLong(cht->row));
 	    PyDict_SetItemString(py_char_attr, "column", PyInt_FromLong(cht->column));
@@ -873,7 +947,7 @@ _wrap_vte_terminal_get_text_range(PyGObject *self, PyObject *args, PyObject *kwa
     	return Py_BuildValue("O", text);
     }
 }
-#line 877 "vte.c"
+#line 951 "vte.c"
 
 
 static PyObject *
@@ -897,6 +971,40 @@ _wrap_vte_terminal_match_add(PyGObject *self, PyObject *args, PyObject *kwargs)
     return PyInt_FromLong(ret);
 }
 
+static PyObject *
+_wrap_vte_terminal_match_set_cursor(PyGObject *self, PyObject *args, PyObject *kwargs)
+{
+    static char *kwlist[] = { "tag", "cursor", NULL };
+    int tag;
+    PyObject *py_cursor;
+    GdkCursor *cursor = NULL;
+
+    if (!PyArg_ParseTupleAndKeywords(args, kwargs, "iO:VteTerminal.match_set_cursor", kwlist, &tag, &py_cursor))
+        return NULL;
+    if (pyg_boxed_check(py_cursor, GDK_TYPE_CURSOR))
+        cursor = pyg_boxed_get(py_cursor, GdkCursor);
+    else {
+        PyErr_SetString(PyExc_TypeError, "cursor should be a GdkCursor");
+        return NULL;
+    }
+    vte_terminal_match_set_cursor(VTE_TERMINAL(self->obj), tag, cursor);
+    Py_INCREF(Py_None);
+    return Py_None;
+}
+
+static PyObject *
+_wrap_vte_terminal_match_remove(PyGObject *self, PyObject *args, PyObject *kwargs)
+{
+    static char *kwlist[] = { "tag", NULL };
+    int tag;
+
+    if (!PyArg_ParseTupleAndKeywords(args, kwargs, "i:VteTerminal.match_remove", kwlist, &tag))
+        return NULL;
+    vte_terminal_match_remove(VTE_TERMINAL(self->obj), tag);
+    Py_INCREF(Py_None);
+    return Py_None;
+}
+
 static PyObject *
 _wrap_vte_terminal_set_emulation(PyGObject *self, PyObject *args, PyObject *kwargs)
 {
@@ -1060,8 +1168,10 @@ static PyMethodDef _PyVteTerminal_methods[] = {
     { "get_audible_bell", (PyCFunction)_wrap_vte_terminal_get_audible_bell, METH_NOARGS },
     { "set_visible_bell", (PyCFunction)_wrap_vte_terminal_set_visible_bell, METH_VARARGS|METH_KEYWORDS },
     { "get_visible_bell", (PyCFunction)_wrap_vte_terminal_get_visible_bell, METH_NOARGS },
+    { "set_scroll_background", (PyCFunction)_wrap_vte_terminal_set_scroll_background, METH_VARARGS|METH_KEYWORDS },
     { "set_scroll_on_output", (PyCFunction)_wrap_vte_terminal_set_scroll_on_output, METH_VARARGS|METH_KEYWORDS },
     { "set_scroll_on_keystroke", (PyCFunction)_wrap_vte_terminal_set_scroll_on_keystroke, METH_VARARGS|METH_KEYWORDS },
+    { "set_color_dim", (PyCFunction)_wrap_vte_terminal_set_color_dim, METH_VARARGS|METH_KEYWORDS },
     { "set_color_bold", (PyCFunction)_wrap_vte_terminal_set_color_bold, METH_VARARGS|METH_KEYWORDS },
     { "set_color_foreground", (PyCFunction)_wrap_vte_terminal_set_color_foreground, METH_VARARGS|METH_KEYWORDS },
     { "set_color_background", (PyCFunction)_wrap_vte_terminal_set_color_background, METH_VARARGS|METH_KEYWORDS },
@@ -1069,6 +1179,7 @@ static PyMethodDef _PyVteTerminal_methods[] = {
     { "set_default_colors", (PyCFunction)_wrap_vte_terminal_set_default_colors, METH_NOARGS },
     { "set_background_image", (PyCFunction)_wrap_vte_terminal_set_background_image, METH_VARARGS|METH_KEYWORDS },
     { "set_background_image_file", (PyCFunction)_wrap_vte_terminal_set_background_image_file, METH_VARARGS|METH_KEYWORDS },
+    { "set_background_tint_color", (PyCFunction)_wrap_vte_terminal_set_background_tint_color, METH_VARARGS|METH_KEYWORDS },
     { "set_background_saturation", (PyCFunction)_wrap_vte_terminal_set_background_saturation, METH_VARARGS|METH_KEYWORDS },
     { "set_background_transparent", (PyCFunction)_wrap_vte_terminal_set_background_transparent, METH_VARARGS|METH_KEYWORDS },
     { "set_cursor_blinks", (PyCFunction)_wrap_vte_terminal_set_cursor_blinks, METH_VARARGS|METH_KEYWORDS },
@@ -1092,6 +1203,8 @@ static PyMethodDef _PyVteTerminal_methods[] = {
     { "get_text_range", (PyCFunction)_wrap_vte_terminal_get_text_range, METH_VARARGS|METH_KEYWORDS },
     { "match_clear_all", (PyCFunction)_wrap_vte_terminal_match_clear_all, METH_NOARGS },
     { "match_add", (PyCFunction)_wrap_vte_terminal_match_add, METH_VARARGS|METH_KEYWORDS },
+    { "match_set_cursor", (PyCFunction)_wrap_vte_terminal_match_set_cursor, METH_VARARGS|METH_KEYWORDS },
+    { "match_remove", (PyCFunction)_wrap_vte_terminal_match_remove, METH_VARARGS|METH_KEYWORDS },
     { "set_emulation", (PyCFunction)_wrap_vte_terminal_set_emulation, METH_VARARGS|METH_KEYWORDS },
     { "get_emulation", (PyCFunction)_wrap_vte_terminal_get_emulation, METH_NOARGS },
     { "set_encoding", (PyCFunction)_wrap_vte_terminal_set_encoding, METH_VARARGS|METH_KEYWORDS },
@@ -1212,6 +1325,6 @@ pyvte_register_classes(PyObject *d)
     }
 
 
-#line 1216 "vte.c"
+#line 1329 "vte.c"
     pygobject_register_class(d, "VteTerminal", VTE_TYPE_TERMINAL, &PyVteTerminal_Type, Py_BuildValue("(O)", &PyGtkWidget_Type));
 }
