@@ -16,8 +16,10 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-#ident "$Id: vteapp.c,v 1.53 2003/04/14 23:31:59 nalin Exp $"
+#ident "$Id: vteapp.c,v 1.60 2003/05/20 05:23:54 nalin Exp $"
+
 #include "../config.h"
+
 #include <sys/ioctl.h>
 #include <sys/stat.h>
 #include <fcntl.h>
@@ -84,21 +86,23 @@ char_size_changed(GtkWidget *widget, guint width, guint height, gpointer data)
 				      GDK_HINT_MIN_SIZE);
 }
 
+static void
+deleted_and_quit(GtkWidget *widget, GdkEvent *event, gpointer data)
+{
+	gtk_widget_destroy(GTK_WIDGET(data));
+	gtk_main_quit();
+}
+
 static void
 destroy_and_quit(GtkWidget *widget, gpointer data)
 {
-	if (GTK_IS_CONTAINER(data)) {
-		gtk_container_remove(GTK_CONTAINER(data), widget);
-	} else {
-		gtk_widget_destroy(widget);
-	}
+	gtk_widget_destroy(GTK_WIDGET(data));
 	gtk_main_quit();
 }
 static void
 destroy_and_quit_eof(GtkWidget *widget, gpointer data)
 {
 	g_print("Detected EOF.\n");
-	destroy_and_quit(widget, data);
 }
 static void
 destroy_and_quit_exited(GtkWidget *widget, gpointer data)
@@ -295,17 +299,6 @@ decrease_font_size(GtkWidget *widget, gpointer data)
 	adjust_font_size(widget, data, -1);
 }
 
-static void
-mess_with_fontconfig(void)
-{
-#ifdef HAVE_XFT2
-	/* Is this even a good idea?  Probably not, since this doesn't expose
-	 * these fonts to the gnome-font-properties capplet. */
-	FcInit();
-	FcConfigAppFontAddDir(NULL, DATADIR "/" PACKAGE "/fonts");
-#endif
-}
-
 static gboolean
 read_and_feed(GIOChannel *source, GIOCondition condition, gpointer data)
 {
@@ -503,7 +496,7 @@ main(int argc, char **argv)
 	 * delete event to the quit function.. */
 	window = gtk_window_new(GTK_WINDOW_TOPLEVEL);
 	g_signal_connect(G_OBJECT(window), "delete_event",
-			 GTK_SIGNAL_FUNC(gtk_main_quit), NULL);
+			 GTK_SIGNAL_FUNC(deleted_and_quit), window);
 
 	/* Create a box to hold everything. */
 	hbox = gtk_hbox_new(0, FALSE);
@@ -511,7 +504,9 @@ main(int argc, char **argv)
 
 	/* Create the terminal widget and add it to the scrolling shell. */
 	widget = vte_terminal_new();
-	gtk_widget_set_double_buffered(widget, dbuffer);
+	if (!dbuffer) {
+		gtk_widget_set_double_buffered(widget, dbuffer);
+	}
 	gtk_box_pack_start(GTK_BOX(hbox), widget, TRUE, TRUE, 0);
 
 	/* Connect to the "char_size_changed" signal to set geometry hints
@@ -529,9 +524,9 @@ main(int argc, char **argv)
 
 	/* Connect to the "eof" signal to quit when the session ends. */
 	g_signal_connect(G_OBJECT(widget), "eof",
-			 G_CALLBACK(destroy_and_quit_eof), widget);
+			 G_CALLBACK(destroy_and_quit_eof), window);
 	g_signal_connect(G_OBJECT(widget), "child-exited",
-			 G_CALLBACK(destroy_and_quit_exited), widget);
+			 G_CALLBACK(destroy_and_quit_exited), window);
 
 	/* Connect to the "status-line-changed" signal. */
 	g_signal_connect(G_OBJECT(widget), "status-line-changed",
@@ -593,9 +588,6 @@ main(int argc, char **argv)
 		vte_terminal_set_emulation(VTE_TERMINAL(widget), terminal);
 	}
 
-	/* Mess with our fontconfig setup. */
-	mess_with_fontconfig();
-
 	/* Set the default font. */
 	if (font != NULL) {
 		vte_terminal_set_font_from_string(VTE_TERMINAL(widget), font);
@@ -677,9 +669,14 @@ main(int argc, char **argv)
 	}
 
 	/* Go for it! */
+	g_object_add_weak_pointer(G_OBJECT(widget), (gpointer*)&widget);
+	g_object_add_weak_pointer(G_OBJECT(window), (gpointer*)&window);
 	gtk_widget_show_all(window);
 
 	gtk_main();
 
+	g_assert(widget == NULL);
+	g_assert(window == NULL);
+
 	return 0;
 }
