@@ -21,7 +21,7 @@
 #ifndef vte_vtefc_h_included
 #define vte_vtefc_h_included
 
-#ident "$Id: vtefc.h,v 1.1 2003/03/05 22:31:08 nalin Exp $"
+#ident "$Id: vtefc.h,v 1.2 2003/05/05 23:23:46 nalin Exp $"
 
 #include <fontconfig/fontconfig.h>
 #include <pango/pango.h>
@@ -29,9 +29,13 @@
 
 G_BEGIN_DECLS
 
+typedef void (*_vte_fc_defaults_cb)(FcPattern *pattern, gpointer data);
+
 gboolean
 _vte_fc_patterns_from_pango_font_desc(const PangoFontDescription *font_desc,
-				      GArray *pattern_array);
+				      GArray *pattern_array,
+				      _vte_fc_defaults_cb defaults_cb,
+				      gpointer defaults_data);
 
 void _vte_fc_connect_settings_changes(GtkWidget *widget, GCallback *changed_cb);
 void _vte_fc_disconnect_settings_changes(GtkWidget *widget,
