@@ -16,7 +16,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-#ident "$Id: vtexft.c,v 1.8 2003/04/24 18:17:17 nalin Exp $"
+#ident "$Id: vtexft.c,v 1.14 2003/05/19 20:55:11 nalin Exp $"
 
 #include "../config.h"
 
@@ -31,6 +31,7 @@
 #include <fontconfig/fontconfig.h>
 #include <X11/Xft/Xft.h>
 #include "debug.h"
+#include "vtebg.h"
 #include "vtedraw.h"
 #include "vtefc.h"
 #include "vtexft.h"
@@ -42,7 +43,7 @@
 #define _(String) String
 #define bindtextdomain(package,dir)
 #endif
- 
+
 #define FONT_INDEX_FUDGE 10
 #define CHAR_WIDTH_FUDGE 10
 
@@ -83,7 +84,8 @@ _vte_xft_font_open(const PangoFontDescription *fontdesc)
 	GArray *patterns;
 
 	patterns = g_array_new(TRUE, TRUE, sizeof(FcPattern*));
-	if (!_vte_fc_patterns_from_pango_font_desc(fontdesc, patterns)) {
+	if (!_vte_fc_patterns_from_pango_font_desc(fontdesc, patterns,
+						   NULL, NULL)) {
 		g_array_free(patterns, TRUE);
 		return NULL;
 	}
@@ -407,37 +409,31 @@ _vte_xft_set_background_color(struct _vte_draw *draw, GdkColor *color)
 }
 
 static void
-_vte_xft_set_background_pixbuf(struct _vte_draw *draw, GdkPixbuf *pixbuf)
+_vte_xft_set_background_image(struct _vte_draw *draw,
+			      enum VteBgSourceType type,
+			      GdkPixbuf *pixbuf,
+			      const char *file,
+			      const GdkColor *color,
+			      double saturation)
 {
 	struct _vte_xft_data *data;
-	GdkColormap *colormap;
 	GdkPixmap *pixmap;
-	GdkBitmap *bitmap;
 
 	data = (struct _vte_xft_data*) draw->impl_data;
 
+	data->xpixmap = -1;
+	data->pixmapw = data->pixmaph = 0;
+	pixmap = vte_bg_get_pixmap(vte_bg_get(), type,
+				   pixbuf, file, color, saturation,
+				   _vte_draw_get_colormap(draw, TRUE));
 	if (GDK_IS_PIXMAP(data->pixmap)) {
 		g_object_unref(G_OBJECT(data->pixmap));
 	}
 	data->pixmap = NULL;
-	data->xpixmap = -1;
-	data->pixmapw = data->pixmaph = 0;
-	if ((pixbuf != NULL) &&
-	    (gdk_pixbuf_get_width(pixbuf) > 0) &&
-	    (gdk_pixbuf_get_height(pixbuf) > 0)) {
-		colormap = gdk_drawable_get_colormap(draw->widget->window);
-		gdk_pixbuf_render_pixmap_and_mask_for_colormap(pixbuf, colormap,
-							       &pixmap, &bitmap,
-							       0);
-		if (bitmap) {
-			g_object_unref(G_OBJECT(bitmap));
-		}
-		if (pixmap) {
-			data->pixmap = pixmap;
-			data->xpixmap = gdk_x11_drawable_get_xid(pixmap);
-			data->pixmapw = gdk_pixbuf_get_width(pixbuf);
-			data->pixmaph = gdk_pixbuf_get_height(pixbuf);
-		}
+	if (GDK_IS_PIXMAP(pixmap)) {
+		data->pixmap = pixmap;
+		data->xpixmap = gdk_x11_drawable_get_xid(pixmap);
+		gdk_drawable_get_size(pixmap, &data->pixmapw, &data->pixmaph);
 	}
 }
 
@@ -766,7 +762,8 @@ struct _vte_draw_impl _vte_draw_xft = {
 	_vte_xft_start,
 	_vte_xft_end,
 	_vte_xft_set_background_color,
-	_vte_xft_set_background_pixbuf,
+	_vte_xft_set_background_image,
+	FALSE,
 	_vte_xft_clear,
 	_vte_xft_set_text_font,
 	_vte_xft_get_text_width,
